<?php

/**
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if( !class_exists( 'jax_lite_admin_notice' ) ) {

	class jax_lite_admin_notice {

		/**
		 * Constructor
		 */

		public function __construct( $fields = array() ) {

			if (
				!get_option( 'jax-lite-hide-notice') &&
				version_compare( PHP_VERSION, JAX_LITE_MIN_PHP_VERSION, '>=' )
			) {

				add_action( 'admin_notices', array(&$this, 'admin_notice') );
				add_action( 'admin_head', array( $this, 'dismiss' ) );

			}

		}

		/**
		 * Dismiss notice.
		 */

		public function dismiss() {

			if ( isset( $_GET['jax-lite-dismiss'] ) && check_admin_referer( 'jax-lite-dismiss-action' ) ) {

				update_option( 'jax-lite-hide-notice', intval($_GET['jax-lite-dismiss']) );
				remove_action( 'admin_notices', array(&$this, 'admin_notice') );

			}

		}

		/**
		 * Admin notice.
		 */

		public function admin_notice() {

		?>

            <div class="notice notice-warning is-dismissible">

            	<p>
            
            		<strong>

						<?php esc_html_e( 'Unlock all premium features of Jax theme like...', 'jax-lite' );  ?>

                    </strong>
                
                </p>
                
                <p class="notice-coupon-message">
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( '600+ Google Fonts', 'jax-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Custom colors', 'jax-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Portfolio section', 'jax-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Unlimited sidebar areas', 'jax-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Lifetime updates', 'jax-lite' ); ?><br/>
                </p>

            	<p>
					
					<strong><?php esc_html_e( 'Pay what you want for the premium version of Jax and receive 11 additional WordPress products as a bonus. (Minimum price allowed: €5)', 'jax-lite' ); ?></strong>

                </p>

            	<p>
					
					<a href="<?php echo esc_url(admin_url( 'themes.php?page=jax-lite-welcome-page&section=free_pro' )); ?>" class="button"><?php esc_html_e( 'Free vs Pro', 'jax-lite' ); ?></a>

                    <a target="_blank" href="<?php echo esc_url( 'https://www.themeinprogress.com/jax-free-responsive-creative-wordpress-theme/?ref=2&campaign=jax-notice' ); ?>" class="button button-primary"><?php esc_html_e( 'Buy now', 'jax-lite' ); ?></a>

            	</p>

            	<p>

            		<strong>

						<?php

							printf(
								'<a href="%1$s" class="dismiss-notice">' . esc_html__( 'Dismiss this notice', 'jax-lite' ) . '</a>',
								esc_url( wp_nonce_url( add_query_arg( 'jax-lite-dismiss', '1' ), 'jax-lite-dismiss-action'))
							);

                        ?>

                    </strong>

            	</p>

            </div>

		<?php

		}

	}

}

new jax_lite_admin_notice();

?>
